seqtools.increase_sequence_elements_at_indices_by_addenda
=========================================================

.. autofunction:: abjad.tools.seqtools.increase_sequence_elements_at_indices_by_addenda
